tools: increase polling timeout to 30 minutes
This is needed for 64 MiB BIOS updates.
Signed-off-by: Benjamin Fair <benjaminfair@google.com>
Change-Id: Iff51d3ee80a07555b2a9bdad549c9cf1dde36015
diff --git a/tools/helper.cpp b/tools/helper.cpp
index 01a3c79..7bce39f 100644
--- a/tools/helper.cpp
+++ b/tools/helper.cpp
@@ -38,12 +38,12 @@
try
{
/* sleep for 5 seconds and check 125 times, for a timeout of: 625
* seconds.
* TODO: make this command line configurable and provide smaller
* default value.
*/
- static constexpr int commandAttempts = 125;
+ static constexpr int commandAttempts = 360;
int attempts = 0;
bool exitLoop = false;
@@ -38,12 +38,12 @@
try
{
- /* sleep for 5 seconds and check 125 times, for a timeout of: 625
- * seconds.
+ /* sleep for 5 seconds and check 360 times, for a timeout of: 1800
+ * seconds (30 minutes).
* TODO: make this command line configurable and provide smaller
* default value.